% estimates of the signal from the GS13 when the BSC-ISI is at the req's

clear
close all

save_plot = true;
%%
freq =  logspace(-1,2,10000);

[BP_num, BP_den] = ellip(8,1, 80, [2*pi*1, 2*pi*3], 'bandpass', 's');
raw_bandpass_1_3 = tf(BP_num, BP_den);


%%
raw_bandpass_1_3_FR = squeeze(freqresp(raw_bandpass_1_3, 2*pi*freq)).';

figure
loglog(freq, abs(raw_bandpass_1_3_FR))
axis([.2, 10, 1e-5, 2])
grid on

just_ones = ones(size(freq));

%% 

rms_just_ones_1_3        = intRMS_Band(just_ones,                freq, 1, 3);
rms_raw_bandpass_1_3_FR  = intRMS_Band(abs(raw_bandpass_1_3_FR), freq, 1, 3);
disp(['The normalized rms should be ',num2str(rms_just_ones_1_3)]);
disp(['The rms of the raw bandpass is ',num2str(rms_raw_bandpass_1_3_FR)]);

amp_scale_1_3 = rms_just_ones_1_3 / rms_raw_bandpass_1_3_FR;

disp(['the correct scale factor for the 1-3 Hz band is ',num2str(amp_scale_1_3)])
norm_bandpass_1_3    = amp_scale_1_3 * raw_bandpass_1_3;
norm_bandpass_1_3_FR = squeeze(freqresp(norm_bandpass_1_3, 2*pi*freq)).';

rms_norm_bandpass_1_3_FR  = intRMS_Band(abs(norm_bandpass_1_3_FR), freq, 1, 3);
disp(['The rms of the normalized bandpass is ',num2str(rms_norm_bandpass_1_3_FR)]);

figure
subplot(211)
ll=loglog(freq, abs(norm_bandpass_1_3_FR));
set(ll,'LineWidth',2)

axis([.1, 30, 1e-5, 2])
grid on
title('Normalized Bandpass filter for 1-3 Hz band')
xlabel('freq (Hz)')
ylabel('transmission amplitude')
tt = text(.11, .1, '1.0591 * ellip(8,1, 80, [2*pi*1, 2*pi*3], ''bandpass'', ''s'')');
set(tt,'FontSize',16)
subplot(212)
ll=semilogx(freq, abs(norm_bandpass_1_3_FR));
set(ll,'LineWidth',2)
axis([.7, 4, .8, 1.2])
grid on
set(gca,'YTick',(.8:.05:1.2))
set(gca,'XTick',[.7 .8 .9 1 2 3 4])

set(gca,'XTickLabel',{'.7', '.8', '.9', '1', '2', '3', '4'})
title('Detail of band pass region')
xlabel('freq (Hz)')
ylabel('transmission amplitude')

tt = text(.72, 1.15, {'Peaks at 1.006, 1.06, 1.20, 1.51, 1.99, 2.49, 2.83, 2.98 Hz',' Peak value 1.059'});
set(tt,'FontSize',16)

tt = text(.72, 0.85, {'Mins at 1.02, 1.12, 1.33, 1.73, 2.26, 2.69, 2.92 Hz',' Min value 0.944'});
set(tt,'FontSize',16)

FillPage('t')
IDfig

if save_plot == true
    print -dpdf normalized_bandpass_1_3Hz.pdf
end
%% 
lowF  = 3;
highF = 10;

[BP_num, BP_den] = ellip(8,1, 80, [2*pi*lowF, 2*pi*highF], 'bandpass', 's');
raw_bandpass     = tf(BP_num, BP_den);
raw_bandpass_FR  = squeeze(freqresp(raw_bandpass, 2*pi*freq)).';

rms_just_ones        = intRMS_Band(just_ones,            freq, lowF, highF);
rms_raw_bandpass_FR  = intRMS_Band(abs(raw_bandpass_FR), freq, lowF, highF);

amp_scale = rms_just_ones / rms_raw_bandpass_FR;

disp(['the correct scale factor for the ',num2str(lowF),' Hz to ', ...
    num2str(highF),' Hz band is ',num2str(amp_scale)]);

norm_bandpass    = amp_scale * raw_bandpass;
norm_bandpass_FR = squeeze(freqresp(norm_bandpass, 2*pi*freq)).';

rms_norm_bandpass_FR  = intRMS_Band(abs(norm_bandpass_FR), freq, lowF, highF);

