%% SOS Coefficients for real-time BLRMS monitor
% updated by BTL on Nov 9, 2011 to simplify the conversion to discrete time
% clear all, close all;

%% General settings
format long;
Ts = 1/512; % sample time
order = 8; % elliptical filter order
ripple = 1; % 1db of ripple
atten = 80; % 80db of attenuation
corner = 0.030; % low pass corner frequency
frequencies = [0.03, 0.1, 0.3, 1, 3, 10, 30.3, 115]; % frequency band limits

%% Lowpass filter coefficients

[num den] = ellip(order*2, ripple, atten, 2*pi*corner,'low','s');
ellip_tf_c = 10^(1/20) * tf(num,den); % normalize to 1
ellip_zpk_d = zpk(c2d(ss(ellip_tf_c),Ts, 'tustin'));

%figure
%bode(ellip_tf_c, ellip_zpk_d);
%step(ellip_tf_c, ellip_zpk_d);

[zz, pp, kk] = zpkdata(ellip_zpk_d);

[low_sos, low_g] = zp2sos(zz{:}, pp{:}, kk);
full_sos{1}.sos = low_sos;
full_sos{1}.gain = low_g;

%% Bandpass filter coefficients

for x = 1:length(frequencies) - 1
    lower = frequencies(x);
    upper = frequencies(x+1);
    [num den] = ellip(order, ripple, atten, [2*pi*lower, 2*pi*upper],'bandpass','s');
    ellip_tf_c = tf(num,den);
    ellip_zpk_d = zpk(c2d(ss(ellip_tf_c),Ts, 'tustin'));
    
    %figure
    %bode(ellip_tf_c, ellip_zpk_d);
    %step(ellip_tf_c, ellip_zpk_d);

    [zz, pp, kk] = zpkdata(ellip_zpk_d);

    [sos, g] = zp2sos(zz{:}, pp{:}, kk);
    full_sos{x+1}.sos = sos;
    full_sos{x+1}.gain = 1.0591 * g;
end

%% RMS coefficients 
alpha = zeros(1,8); % actual coefficients
tau = zeros(1,8); % decay time constants
tau(1) = 8 / frequencies(1); % ~50/(2*pi) / geometric mean freq
alpha(1) = Ts / (Ts + tau(1));
for x = 1:length(frequencies)-1
      tau(x+1) = max(1, 8 / sqrt(frequencies(x) * frequencies(x+1)));
      alpha(x+1) = Ts / (Ts + tau(x+1));
end

%% write to a text file that we can just copy into C
coefficients = '';
gains  = '{';
alphas = '{';
taus   = '{';

for k=1:length(frequencies)
    for j=1:order
        coefficients = [coefficients; sprintf(' {%+.15f, %+.15f, %+.15f, %+.15f},  ', ...
            full_sos{k}.sos(j,2:3), full_sos{k}.sos(j,5:6))];
    end
    coefficients(order*(k-1) + 1, 1) = '{';
    coefficients(order*k, end-2:end-1) = '},';
    gains = strcat(gains, sprintf(' %.15f,', full_sos{k}.gain));
    alphas = strcat(alphas, sprintf(' %.15f,', alpha(k)));
    taus   = strcat(taus, sprintf(' %.15f,', tau(k)));
end
coefficients(end,end-1) = ' ';
gains(end, end-1:end) = '};';
alphas(end, end-1:end) = '};';

taus
coefficients
gains
alphas

%% plotting data (temp)
%{
blrms = importdata('blrms_test.txt');
x_axis = 0:1/4096:(length(blrms.data)-1)/4096;
figure;
plot(x_axis, blrms.data);
legend(blrms.colheaders) 
%}

